%global major_ver 1.6

Name:           gnumed
Version:        %{major_ver}.7
Release:        3%{?dist}
Summary:        The GNUmed client

License:        GPLv2+
URL:            http://wiki.%{name}.de
Source0:        http://www.%{name}.de/downloads/client/%{major_ver}/%{name}-client.%{version}.tgz

BuildRequires:  desktop-file-utils
BuildRequires:  python-devel

BuildArch:      noarch

# Required to use the software properly
Requires:  python
Requires:  gnuplot-py
Requires:  libreoffice-pyuno
Requires:  libxslt-python
Requires:  python-enchant
Requires:  python-psycopg2 >= 2.0.10
Requires:  python-egenix-mx-base
Requires:  python-hl7
Requires:  python-httplib2
Requires:  python-libxml2
Requires:  python-sane
Requires:  python-simplejson
Requires:  wxPython >= 2.8

# Recommended
Recommends:  aspell
Recommends:  file
Recommends:  gnupg
Recommends:  ImageMagick
Recommends:  perl-Image-ExifTool
# not packaged yet
# recommended DICOM viewer
# Requires:  ginkgocadx
# other DICOM viewers
# Requires:  aeskulap
# Requires:  amide
# /end DICOM
# Requires:  gtklp
# not needed, gnumed tries using the Python wrapper which we don't have
# and revert to using file before using the extract binary
# note: if using this, patch client/pycommon/gmMimeLib.py
# Requires:  libextractor
Requires:  texlive-latex
Requires:  xmedcon
Requires:  xsane


%description
This is the GNUmed Electronic Medical Record.
Its purpose is to enable doctors to keep a medically sound record
on their patients' health. Currently it is not fully featured. The
features provided are, however, tested, in use, and considered
stable. This package does NOT yet provide functionality for billing
and stock keeping.

While the GNUmed team has taken the utmost care to make sure the
medical records are safe at all times you still need to make sure
you are taking appropriate steps to backup the medical data to a
safe place at appropriate intervals. Do test your backup and
disaster recovery procedures, too !

Protect your data! GNUmed itself comes without any warranty
whatsoever. You have been warned.

Homepage: http://gnumed.org/

This package contains the wxpython client.

Authors:
--------
    Sebastian Hilbert <sebastian.hilbert@gmx.net>
    Karsten Hilbert <karsten.hilbert@gmx.net>
    GNUmed team


%package doc
Summary:    Documentation for %{name}
BuildArch:  noarch
Requires:   %{name} = %{version}-%{release}
Provides:   %{name}-docs = %{version}-%{release}
# last release before rename is 0.9.9-5
Obsoletes:  %{name}-docs < 1.0.0

%description doc
The documentation for %{name}

%prep
%setup -q -n %{name}-client.%{version}
# fix EOL encoding
pushd client/doc/user-manual/rsrc/Gnumed/LegacyAppConfiguration
for f in gnumed.conf.modus{1,2} GDT.ini;
do
    touch -r $f $f.tstamp \
    && sed -i 's/\r//' $f \
    && touch -r $f.tstamp $f \
    && rm $f.tstamp
done

for f in GDT.ini;
do
    iconv -f iso8859-1 -t utf-8 $f > $f.conv \
    && touch -r $f $f.conv && mv -f $f.conv $f
done
popd

%build
# Nothing here

%install
mkdir -p $RPM_BUILD_ROOT/%{_sysconfdir}/%{name}
cp -p client/connectors/gm_ctl_client.conf $RPM_BUILD_ROOT/%{_sysconfdir}/%{name}/gm_ctl_client.conf
cp -p client/doc/%{name}.conf.example $RPM_BUILD_ROOT/%{_sysconfdir}/%{name}/%{name}.conf
cp -p client/etc/%{name}/%{name}-client.conf.example $RPM_BUILD_ROOT/%{_sysconfdir}/%{name}/%{name}-client.conf

mkdir -p $RPM_BUILD_ROOT%{_bindir}
cp -p client/%{name} $RPM_BUILD_ROOT%{_bindir}/%{name}

mkdir -p $RPM_BUILD_ROOT%{_datadir}/%{name}/bitmaps
cp  -av client/bitmaps/{e*,gnu*,serpent}.png $RPM_BUILD_ROOT%{_datadir}/%{name}/bitmaps/

# Locale files
for i in "fr" "de" "es" "it" "nb" "nl" "pl" "pt_BR" "ru"; do
    mkdir -p $RPM_BUILD_ROOT%{_datadir}/locale/"$i"/LC_MESSAGES/
    cp -p client/po/"$i"-%{name}.mo $RPM_BUILD_ROOT%{_datadir}/locale/"$i"/LC_MESSAGES/%{name}.mo
done
%find_lang %{name}

mkdir -p $RPM_BUILD_ROOT%{_datadir}/pixmaps
cp -p client/bitmaps/gm_icon-serpent_and_gnu.{png,svg} $RPM_BUILD_ROOT%{_datadir}/pixmaps/

mkdir -p -m 755  $RPM_BUILD_ROOT%{python_sitelib}/Gnumed/business
cp -pr client/business $RPM_BUILD_ROOT%{python_sitelib}/Gnumed

mkdir -p -m 755 $RPM_BUILD_ROOT%{python_sitelib}/Gnumed/exporters
cp -pr client/exporters $RPM_BUILD_ROOT%{python_sitelib}/Gnumed

mkdir -p -m 755 $RPM_BUILD_ROOT/%{python_sitelib}/Gnumed/wxGladeWidgets
# Remove shebang
sed -i "/\/usr\/bin\/env/d" client/wxGladeWidgets/*
cp -pr client/wxGladeWidgets  $RPM_BUILD_ROOT%{python_sitelib}/Gnumed

mkdir -p -m 755 $RPM_BUILD_ROOT/%{python_sitelib}/Gnumed/wxpython/gui
cp -pr client/wxpython $RPM_BUILD_ROOT%{python_sitelib}/Gnumed
cp -pr client/wxpython/gui $RPM_BUILD_ROOT%{python_sitelib}/Gnumed/wxpython

sed -i "/\/usr\/bin\/env/d" client/%{name}.py
cp -pr client/%{name}.py $RPM_BUILD_ROOT%{python_sitelib}/Gnumed

mkdir -p $RPM_BUILD_ROOT/%{_datadir}/applications/
mkdir -p $RPM_BUILD_ROOT/%{_datadir}/icons/
cp client/%{name}-client.desktop $RPM_BUILD_ROOT%{_datadir}/applications/
cp client/bitmaps/%{name}logo.png $RPM_BUILD_ROOT%{_datadir}/icons/%{name}logo.png

desktop-file-install \
    --vendor='' \
    --dir $RPM_BUILD_ROOT%{_datadir}/applications \
    $RPM_BUILD_ROOT%{_datadir}/applications/%{name}-client.desktop

# pycommon
mkdir -p $RPM_BUILD_ROOT%{python_sitelib}/Gnumed/pycommon
cp -r client/pycommon $RPM_BUILD_ROOT%{python_sitelib}/Gnumed
cp -r client/__init__.py $RPM_BUILD_ROOT%{python_sitelib}/Gnumed

# Man pages
mkdir -p $RPM_BUILD_ROOT%{_mandir}/man1/
cp client/doc/*.1 $RPM_BUILD_ROOT%{_mandir}/man1/

# Extra binaries
install -p -m 0755 external-tools/gm-print_doc -t $RPM_BUILD_ROOT/%{_bindir}/
install -p -m 0755 external-tools/gm-download_data -t $RPM_BUILD_ROOT/%{_bindir}/

# Wrapper
cat << EOF > gm_ctl_client
#!/bin/bash
python client/connectors/gm_ctl_client.py --conf-file=%{_sysconfdir}/%{name}/gm_ctl_client.conf
EOF
install -p -m 0755 gm_ctl_client -t $RPM_BUILD_ROOT/%{_bindir}/

%files -f %{name}.lang
%license client/LICENSE
%doc client/CHANGELOG client/GnuPublicLicense.txt
%{_bindir}/%{name}
%{_bindir}/gm-print_doc
%{_bindir}/gm_ctl_client
%{_bindir}/gm-download_data
%dir %{_sysconfdir}/%{name}
%config(noreplace) %{_sysconfdir}/%{name}/*
%{_datadir}/%{name}/
%{_datadir}/pixmaps/gm_icon-serpent_and_gnu.*
%{_datadir}/icons/%{name}logo.png
%{_datadir}/applications/%{name}-client.desktop
%{python_sitelib}/Gnumed/
%{_mandir}/man1/%{name}.1*
%{_mandir}/man1/gm*.1*

%files doc
%doc client/doc/user-manual/*

%changelog
* Fri Feb 10 2017 Fedora Release Engineering <releng@fedoraproject.org> - 1.6.7-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Tue Jul 19 2016 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.6.7-2
- https://fedoraproject.org/wiki/Changes/Automatic_Provides_for_Python_RPM_Packages

* Thu Jul  7 2016 Michel Alexandre Salim <salimma@fedoraproject.org> - 1.6.7-1
- Update to 1.6.7

* Wed Feb 03 2016 Fedora Release Engineering <releng@fedoraproject.org> - 1.4.8-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Wed Jun 17 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.4.8-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Sat Jan 17 2015 Michel Alexandre Salim <salimma@fedoraproject.org> - 1.4.8-4
- Fix dependency name properly

* Sat Jan 17 2015 Michel Alexandre Salim <salimma@fedoraproject.org> - 1.4.8-3
- Fix dependency name: python-pillow-sane, not python-imaging-sane

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.4.8-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Wed May 21 2014 Michel Salim <salimma@fedoraproject.org> - 1.4.8-1
- Update to 1.4.8

* Wed Jan 29 2014 Michel Salim <salimma@fedoraproject.org> - 1.4.5-1
- Update to 1.4.5

* Sat Aug 03 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.3.6-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Fri Jul  5 2013 Michel Salim <salimma@fedoraproject.org> - 1.3.6-1
- Update to 1.3.6

* Fri Jun 14 2013 Michel Salim <salimma@fedoraproject.org> - 1.3.5-1
- Update to 1.3.5

* Wed May 15 2013 Michel Salim <salimma@fedoraproject.org> - 1.3.4-1
- Update to 1.3.4

* Mon Apr  8 2013 Michel Salim <salimma@fedoraproject.org> - 1.3.2-1
- Update to 1.3.2

* Sat Mar 23 2013 Michel Salim <salimma@fedoraproject.org> - 1.3.1-1
- Update to 1.3.1

* Mon Mar 18 2013 Michel Salim <salimma@fedoraproject.org> - 1.3.0-1
- Update to 1.3.0

* Sat Mar 16 2013 Michel Salim <salimma@fedoraproject.org> - 1.2.9-1
- Update to 1.2.9

* Thu Feb 14 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.2.6-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Wed Nov 21 2012 Michel Salim <salimma@fedoraproject.org> - 1.2.6-1
- Update to 1.2.6
- Drop additional readme, the warning about openSUSE is not applicable here
- Fix end-of-line and encoding of included files

* Sat Aug  4 2012 Michel Salim <salimma@fedoraproject.org> - 1.1.18-1
- Update to 1.1.18

* Thu Jul 19 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.1.14-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Fri Jun  1 2012 Michel Salim <salimma@fedoraproject.org> - 1.1.14-1
- Update to 1.1.14

* Fri Jan 06 2012 Ankur Sinha <ankursinha AT fedoraproject DOT org> - 0.9.9-5
- spec bump for gcc 4.7 rebuild

* Mon Aug 15 2011 Ankur Sinha <ankursinha AT fedoraproject DOT org> - 0.9.9-4
- Improve the Requires
- Mailed upstream requesting update of the FSF address
- Added a wrapper
- Added more binaries. Refer for file list:
- http://packages.debian.org/sid/all/gnumed-client/filelist

* Sat Aug 13 2011 Ankur Sinha <ankursinha AT fedoraproject DOT org> - 0.9.9-3
- Include upstream's email clarifying the license
- Added a for loop to handle locale files

* Tue Aug 09 2011 Ankur Sinha <ankursinha AT fedoraproject DOT org> - 0.9.9-2
- Remove doc dependency
- Put man pages in correct sub packages
- Merge subpackages, modularity isn't really required here, let docs be.
- Correct license

* Sun Aug 07 2011 Ankur Sinha <ankursinha AT fedoraproject DOT org> - 0.9.9-1
- Initial rpmbuild
- Based on Paul Grinberg's spec for the rpm on the official website.
